appname = "nodcast"
appauthor = "App"
user = 'na'
profile = "default"

def set_app(name,author="App",_user="na",_profile="default"):
    global appname, appauthor, user, profile
    appname = name
    appauthor = author
    user = _user
    profile = _profile




mode_colors = {
    "s) speak aloud": 22,
    "z) auto next": 22,
    "s) speak on": 161,
    "paused": 161,
}
nod_colors = {
    "yes": 77,
    "OK": 36,
    "OK, I get it now": 36,
    "I agree!": 22,
    "answer": 41,
    "idea": 151,
    "correct": 30,
    "incorrect": 161,
    "background": 93,
    "archive": 145,
    "okay": 36,
    "okay, okay!": 25,
    "okay, go on": 30,
    "okay?": 240,
    "not reviewed": 143,
    "goal": 22,
    "got an idea!": 32,
    "skipped": 245,
    "skip": 245,
    "I see!": 71,
    "interesting!": 76,
    "favorite!": 219,
    "interesting, so?": 76,
    "proposed solution": 32,
    "contribution": 77,
    "feature": 77,
    "constraint": 97,
    "important!": 141,
    "point!": 142,
    "main idea!": 142,
    "has an idea!": 115,
    "didn't get!": 161,
    "didn't get": 161,
    "unclear": 161,
    "question": 136,
    "comment": 141,
    "didn't get the article": 161,
    "didn't get, needs review": 161,
    "okay, never mind": 145,
    "what?!": 161,
    "what?! needs review": 161,
    "don't think so": 179,
    "not sure!": 179,
    "what?!": 31,
    "didn't get, so?": 196,
    "so?": 39,
    "Let's continue": 39,
    "continue": 39,
    "okay, continue": 39,
    "okay, so?": 39,
    "almost got the idea?": 32,
    "explain more": 178,
    "why?": 59,
    "needs review": 177,
    "review later": 177,
    "to read later": 177,
    "check later": 186,
    "problem": 179,
    "definition": 250,
    "got it!": 69,
    "got the idea!": 69,
}

cW = 7
cR = 1
cG = 30
cY = 5
cB = 27
clB = 33
cPink = 15
cC = 9
clC = 16
clY = 13
cGray = 10
clGray = 250
clG = 12
cllC = 83
cO = 94
back_color = None

TEXT_COLOR = 35 
ITEM_COLOR = 32 
TITLE_COLOR = 30
DIM_COLOR = 233
COMMENT_COLOR = 39

CUR_ITEM_COLOR = 100
HL_COLOR = 101
INPUT_COLOR = 102
INFO_COLOR = 103
ERR_COLOR = 104
MSG_COLOR = 105
WARNING_COLOR = 106
TEMP_COLOR = 107
TEMP_COLOR2 = 108
SEL_ITEM_COLOR = 109

color_map = {
    "cur-item-color": CUR_ITEM_COLOR,
    "sel-item-color": SEL_ITEM_COLOR,
    "highlight-color": HL_COLOR,
    "hl-text-color": HL_COLOR,
    "back-color": TEXT_COLOR,
    "input-color": INPUT_COLOR,
}

hl_colors = [(137,52), (234, 243), (234, 137), (234, 95), (137,236), (137,234), (144, 234), (95,233), (95, 17), (245,17), (245,235)]




from pathlib import Path
import shutil
import importlib.resources as res
import os
import platform
import yaml
import shutil

def read_new_yaml():
    """
    Read 'new.yaml' file from the parent of the 'nodcast' package's 'resources' directory
    and return its parsed YAML content.
    """
    try:
        # Locate the parent directory of the 'nodcast' package
        parent_path = res.files("nodcast").parent
        yaml_path = parent_path / "docs" / "new.yaml"

        with res.as_file(yaml_path) as actual_yaml_path:
            if not actual_yaml_path.exists():
                raise FileNotFoundError(f"'new.yaml' not found at {actual_yaml_path}")
            with open(actual_yaml_path, "r", encoding="utf-8") as f:
                return yaml.safe_load(f)

    except Exception as e:
        print(f"Error reading new.yaml: {e}")
        return None


def get_documents_path(appname="nodcast", as_str=True):
    """Return cross-platform Documents/<appname> path and create it."""
    if platform.system() == "Windows":
        doc_base = Path(os.path.join(os.environ.get("USERPROFILE", ""), "Documents"))
    else:
        doc_base = Path.home() / "Documents"
    path = doc_base / appname
    path.mkdir(parents=True, exist_ok=True)
    return str(path) if as_str else path

def copy_examples_to_docs(profile = "default", doc_path=None):
    """Copy packaged examples to user's Documents/nodcast/examples/, only if missing."""
    if doc_path is None:
        doc_path = get_documents_path("nodcast", as_str=False)
    else:
        doc_path = Path(doc_path)

    dest = doc_path / profile 
    try:
        # locate 'docs/examples' within installed package
        examples_pkg_path = res.files("nodcast").parent / "docs" / "examples"

        with res.as_file(examples_pkg_path) as src_dir:
            if not src_dir.exists():
                print("No examples found in package.")
                return

            dest.mkdir(parents=True, exist_ok=True)

            copied_any = False
            for item in src_dir.rglob("*"):
                rel = item.relative_to(src_dir)
                target = dest / rel

                if item.is_dir():
                    target.mkdir(exist_ok=True)
                else:
                    if not target.exists():
                        shutil.copy2(item, target)
                        copied_any = True

            if copied_any:
                print(f"Example files copied to {dest}")
            else:
                print(f"Examples already exist in {dest}, no files copied.")

    except Exception as e:
        print(f"Failed to copy examples: {e}")

def get_profiles(doc_path=None, profile_str="profile:"):
    if doc_path is None:
        doc_path = get_documents_path("nodcast", as_str=False)
    else:
        doc_path = Path(doc_path)

    # Scan directories under doc_path
    profiles = []
    if doc_path.exists():
        for entry in doc_path.iterdir():
            if entry.is_dir() and entry.name not in ("__pycache__"):
                # For example, each folder could represent a user profile
                profiles.append(entry.name)

    return profiles




#!/usr/bin/env python3

"""pdfSummarizer.py: This script summarizes text provided in a PDF file."""

import os
import nltk
import pytesseract
import re
from pdf2image import convert_from_path
from nltk.corpus import stopwords
from nltk.tokenize import word_tokenize, sent_tokenize
from nltk.stem.snowball import SnowballStemmer
from PIL import Image
nltk.download("stopwords")
nltk.download("punkt")


import slate3k as slate
def extractText(file):
    pdfFileObj = open(file, "rb")
    pdfPages = slate.PDF(pdfFileObj)

    # Extract text from PDF file
    text = ""
    for page in pdfPages:
        text += page
    return text


def extractOCR(file):
    pages = convert_from_path(file, 500)

    image_counter = 1
    for page in pages:
        filename = "page_" + str(image_counter) + ".jpg"
        page.save(filename, "JPEG")
        image_counter = image_counter + 1

    limit = image_counter-1
    text = ""
    for i in range(1, limit + 1):
        filename = "page_" + str(i) + ".jpg"
        page = str(((pytesseract.image_to_string(Image.open(filename)))))
        page = page.replace("-\n", "")
        text += page
        os.remove(filename)
    return text


def summarize(text):
    # Process text by removing numbers and unrecognized punctuation
    processedText = re.sub("’", "'", text)
    processedText = re.sub("[^a-zA-Z' ]+", " ", processedText)
    stopWords = set(stopwords.words("english"))
    words = word_tokenize(processedText)

    # Normalize words with Porter stemming and build word frequency table
    stemmer = SnowballStemmer("english", ignore_stopwords=True)
    freqTable = dict()
    for word in words:
        word = word.lower()
        if word in stopWords:
            continue
        elif stemmer.stem(word) in freqTable:
            freqTable[stemmer.stem(word)] += 1
        else:
            freqTable[stemmer.stem(word)] = 1

    # Normalize every sentence in the text
    sentences = sent_tokenize(text)
    stemmedSentences = []
    sentenceValue = dict()
    for sentence in sentences:
        stemmedSentence = []
        for word in sentence.lower().split():
            stemmedSentence.append(stemmer.stem(word))
        stemmedSentences.append(stemmedSentence)

    # Calculate value of every normalized sentence based on word frequency table
    # [:12] helps to save space
    for num in range(len(stemmedSentences)):
        for wordValue in freqTable:
            if wordValue in stemmedSentences[num]:
                if sentences[num][:12] in sentenceValue:
                    sentenceValue[sentences[num][:12]] += freqTable.get(wordValue)
                else:
                    sentenceValue[sentences[num][:12]] = freqTable.get(wordValue)

    # Determine average value of a sentence in the text
    sumValues = 0
    for sentence in sentenceValue:
        sumValues += sentenceValue.get(sentence)

    average = int(sumValues / len(sentenceValue))

    # Create summary of text using sentences that exceed the average value by some factor
    # This factor can be adjusted to reduce/expand the length of the summary
    summary = ""
    for sentence in sentences:
            if sentence[:12] in sentenceValue and sentenceValue[sentence[:12]] > (1.0 * average):
                summary += " " + " ".join(sentence.split())

    # Process the text in summary and write it to a new file
    summary = re.sub("’", "'", summary)
    summary = re.sub("[^a-zA-Z0-9'\"():;,.!?— ]+", " ", summary)
    return summary





rc_inst = """
    Please find the answers to the following questions in the given text. To do this, navigate to each question, then press s to start reading the text.
    To find the answer, scan the text sentence by sentence with arrow keys. Then press <Enter> on the sentence containing the answer. If it's the correct sentence, the sentence is highlighted in green, otherwise, it's highlighted in red.
    To mark the answer span,  navigate to its starting word, then either hold the <Shift> key or press the v key, then move forward to the ending word and press v again.
    In the end, press <Enter> to validate your answer. Some questions cannot be answered by the given text, press s to stop reading and return back to the question and then press - to specify it as 'impossible to answer'. You can also skip a question by pressing <Left> when it's selected.
"""




import re
alphabets= "([A-Za-z])"
prefixes = "(Mr|St|Mrs|Ms|Dr)[.]"
suffixes = "(Inc|Ltd|Jr|Sr|Co)"
starters = "(Mr|Mrs|Ms|Dr|He\s|She\s|It\s|They\s|Their\s|Our\s|We\s|But\s|However\s|That\s|This\s|Wherever)"
acronyms = "([A-Z][.][A-Z][.](?:[A-Z][.])?)"
websites = "[.](com|net|org|io|gov)"
digits = "([0-9]+)"

def rplit_into_sentences(text):
    sents = nltk.sent_tokenize(text)
    return sents

def qplit_into_sentences(text):
    try:
        import nltk
        try:
            sents = nltk.sent_tokenize(text)
            return sents
        except LookupError:
            nltk.download('punkt')
            sents = nltk.sent_tokenize(text)
            return sents
    except ImportError as e:
        return rplit_into_sentences(text)


def split_into_sentences(text, debug=False, limit=15, split_on=['.', '?', '!', ':']):
    if not text:
        return []
    text = " " + text + "  "
    rep = {
        "Ph.D.": "Ph<prd>D<prd>",
        "[FRAG]": "<stop>",
        "et al.": "et al<prd>",
        " et.": " et<prd>",
        "e.g.": "e<prd>g<prd>",
        "e.g": "e<prd>g",
        "vs.": "vs<prd>",
        "www.": "www<prd>",
        "etc.": "etc<prd>",
        "i.e.": "i<prd>e<prd>",
        "...": "<prd><prd><prd>",
        "•": "<stop>•"
    }

    rep = dict((re.escape(k), v) for k, v in rep.items())
    pattern = re.compile("|".join(rep.keys()))
    text = pattern.sub(lambda m: rep[re.escape(m.group(0))], text)

    # simple sentence split based on stop markers
    sentences = re.split(r'(?<=[.?!])\s+', text.strip())
    sentences = [s.strip() for s in sentences if s.strip()]

    if debug:
        print(f"split_into_sentences: {sentences}")

    return sentences




import logging
import pickle
from pathlib import Path
from appdirs import *
import os
try:
    from nodcast.util.common import *
except:
    from common import *

def save_obj(obj, name, directory, data_dir=True, common=False):
    if obj is None or name.strip() == "":
        logging.info(f"Empty object to save: {name}")
        return
    if not data_dir or name.startswith("chk_def_"):
        folder = directory
    elif common:
        folder = user_data_dir(appname, appauthor) + "/" + directory  
    else:
        folder = user_data_dir(appname, appauthor) + "/profiles/" + profile + "/" + directory
    Path(folder).mkdir(parents=True, exist_ok=True)
    fname = os.path.join(folder, name + '.pkl')
    with open(fname, 'wb') as f:
        pickle.dump(obj, f, pickle.HIGHEST_PROTOCOL)


def load_obj(name, directory, default=None, data_dir=True, common =False):
    if not data_dir:
        folder = directory
    elif common:
        folder = user_data_dir(appname, appauthor) + "/" + directory  
    else:
        folder = user_data_dir(appname, appauthor) + "/profiles/" + profile + "/" + directory

    fname = os.path.join(folder, name + ".pkl")
    obj_file = Path(fname)
    if not obj_file.is_file():
        return default
    with open(fname, 'rb') as f:
        return pickle.load(f)


def is_obj(name, directory, common = False):
    if common:
        folder = user_data_dir(appname, appauthor) + "/" + directory  
    else:
        folder = user_data_dir(appname, appauthor) + "/profiles/" + profile + "/" + directory
    if not name.endswith('.pkl'):
        name = name + '.pkl'
    fname = os.path.join(folder, name)
    obj_file = Path(fname)
    if not obj_file.is_file():
        return False
    else:
        return True
